@@ -44,9 +44,10 @@ class TwythonStreamerTypes(object):
 class TwythonStreamerTypesStatuses(object):
     """Class for different statuses endpoints
 
-    Available so TwythonStreamer.statuses.filter() is available.
-    Just a bit cleaner than TwythonStreamer.statuses_filter(),
-    statuses_sample(), etc. all being single methods in TwythonStreamer
+    Available so :meth:`TwythonStreamer.statuses.filter()` is available.
+    Just a bit cleaner than :meth:`TwythonStreamer.statuses_filter()`,
+    :meth:`statuses_sample()`, etc. all being single methods in 
+    :class:`TwythonStreamer`.
 
     """
     def __init__(self, streamer):
@@ -59,7 +60,7 @@ class TwythonStreamerTypesStatuses(object):
         :param \*\*params: Parameters to send with your stream request
 
         Accepted params found at:
-        https://dev.twitter.com/docs/api/1.1/post/statuses/filter
+        https://developer.twitter.com/en/docs/tweets/filter-realtime/api-reference/post-statuses-filter
         """
         url = 'https://stream.twitter.com/%s/statuses/filter.json' \
               % self.streamer.api_version
@@ -71,7 +72,7 @@ class TwythonStreamerTypesStatuses(object):
         :param \*\*params: Parameters to send with your stream request
 
         Accepted params found at:
-        https://dev.twitter.com/docs/api/1.1/get/statuses/sample
+        https://developer.twitter.com/en/docs/tweets/sample-realtime/api-reference/get-statuses-sample
         """
         url = 'https://stream.twitter.com/%s/statuses/sample.json' \
               % self.streamer.api_version
@@ -95,7 +96,7 @@ class TwythonStreamerTypesStatuses(object):
         :param \*\*params: Parameters to send with your stream request
 
         Accepted params found at:
-        https://dev.twitter.com/docs/api/1.1/post/statuses/filter
+        https://developer.twitter.com/en/docs/tweets/filter-realtime/api-reference/post-statuses-filter
         """
         self.params = params
 
@@ -104,4 +105,4 @@ class TwythonStreamerTypesStatuses(object):
 
         url = 'https://stream.twitter.com/%s/statuses/filter.json' \
               % self.streamer.api_version
-        self.streamer._request(url, 'POST', params=self.params)	
+        self.streamer._request(url, 'POST', params=self.params)
